@@ -5,7 +5,7 @@ use warnings;
 
 use base qw( Log::Dispatch::File );
 
-our $VERSION = '2.52';
+our $VERSION = '2.53';
 
 use Fcntl qw(:DEFAULT :flock);
 
@@ -28,7 +28,7 @@ sub log_message {
     my $self = shift;
 
     $self->SUPER::log_message(@_);
-    return unless $self->{close};
+    return if $self->{close};
 
     flock( $self->{fh}, LOCK_UN );
 }
@@ -47,7 +47,7 @@ Log::Dispatch::File::Locked - Subclass of Log::Dispatch::File to facilitate lock
 
 =head1 VERSION
 
-version 2.52
+version 2.53
 
 =head1 SYNOPSIS
 
@@ -72,6 +72,11 @@ version 2.52
 This module acts exactly like L<Log::Dispatch::File> except that it
 obtains an exclusive lock on the file while opening it.
 
+Note that if you are using this output because you want to write to a file
+from multiple processes, you should open the file with the append C<mode>
+(C<<< >> >>>), or else it's quite likely that one process will overwrite
+another.
+
 =head1 SEE ALSO
 
 L<perlfunc/flock>
